const API_BASE_URL = "https://bci.carpete.pt/api"; // URL base da API

/**
 * Função genérica para fazer requisições à API
 * @param {string} endpoint - O endpoint da API (ex: "/users")
 * @param {string} method - Método HTTP (GET, POST, PUT, DELETE)
 * @param {Object} data - Dados a serem enviados no corpo da requisição (opcional)
 * @param {Object} headers - Headers adicionais (opcional)
 * @returns {Promise<Object>} - Resposta da API
 */
async function apiRequest(endpoint, method = "GET", data = null, headers = {}) {
    const url = `${API_BASE_URL}${endpoint}`;

    // Headers padrão
    const defaultHeaders = {
        "Content-Type": "application/json",
        ...headers,
    };

    // Se houver um token salvo (autenticação)
    const token = localStorage.getItem("token");
    if (token) {
        defaultHeaders["Authorization"] = `Bearer ${token}`;
    }

    const options = {
        method,
        headers: defaultHeaders,
    };

    if (data) {
        options.body = JSON.stringify(data);
    }

    try {
        const response = await fetch(url, options);
        const result = await response.json();

        if (response.ok) {
            return { success: true, result };
        } else {
            return { success: false, message: result.message || "Erro na requisição" };
        }
    } catch (error) {
        console.error(`Erro na API (${method} ${endpoint}):`, error.message);
        return { success: false, message: error.message };
    }
}

/**
 * Métodos específicos para cada funcionalidade
 */
const API = {
    // Auth
    register: (userData) => apiRequest("/auth/register", "POST", userData),
    login: (userCredentials) => apiRequest("/auth/login", "POST", userCredentials),
    validateToken: () => apiRequest("/auth/authenticated", "GET"),
    validateAdminToken: () => apiRequest("/auth/adminAuthenticated", "GET"),
    recoverPasswordEmail: (email) => apiRequest("/auth/password-recovery", "POST", { email }),

    // User Data
    getUserData: () => apiRequest("/users/me", "GET"),
    getChartData: () => apiRequest("/users/me/chart", "GET"),
    getUserCasinoAccounts: () => apiRequest("/users/me/casino_accounts", "GET"),
    getTransactions: () => apiRequest("/users/me/transactions", "GET"),
    getUserDebts: () => apiRequest("/users/me/debts", "GET"),
    getUserWithdrawals: () => apiRequest("/users/me/withdrawals", "GET"),
    getProfits: () => apiRequest("/users/me/profits", "GET"),
    getPreferences: () => apiRequest("/users/me/preferences", "GET"),
    updatePreferences: (preferences) => apiRequest("/users/me/preferences", "PUT", preferences),
    changePassword: (currentPassword, newPassword) => apiRequest("/users/me/change_password", "PATCH", { currentPassword, newPassword }),
    withdraw: (amount) => apiRequest("/users/me/withdraw", "POST", { amount }),

    // Admin
    fetchUsers: () => apiRequest("/users/", "GET"),
    fetchCasinoAccounts: () => apiRequest("/casino_accounts/", "GET"),
    fetchWithdrawals: () => apiRequest("/withdrawals/", "GET"),
    fetchDebts: () => apiRequest("/debts/", "GET"),
    deleteUser: (user_id) => apiRequest("/users/" + user_id, "DELETE"),
    deleteDebt: (debt_id) => apiRequest("/debts/" + debt_id, "DELETE"),
    deleteCasinoAccount: (account_id) => apiRequest("/casino_accounts/" + account_id, "DELETE"),
    deleteWithdrawal: (withdrawal_id) => apiRequest("/withdrawals/" + withdrawal_id, "DELETE"),
    updateDebt: (debt_id, status) => apiRequest("/debts/" + debt_id, "PUT",  { status: status}),
    updateWithdrawal: (withdrawal_id, status) => apiRequest("/withdrawals/" + withdrawal_id, "PUT",  { status: status}),
    updateCasinoAccount: (account_id, params) => apiRequest("/casino_accounts/" + account_id, "PUT", params),
    addUserBonus: (user_id, amount) => apiRequest("/users/addbonus/" + user_id , "POST", { amount: amount }),
};

export default API;
